package com.chinaitop.depot.intelligent.grainsituation.model;

import java.math.BigDecimal;
import java.util.Date;

public class TCcvalue {
    private String id;

    private String orgId;

    private String vCcCode;

    private String zZdCode;

    private String vCfCode;

    private Integer vMax;

    private Integer vMin;

    private BigDecimal vAvg;

    private Date vUpdateTime;

    private String dataSource;

    private String hcjcdh;

    /**
     * 测虫设备code
     * @return id 测虫设备code
     */
    public String getId() {
        return id;
    }

    /**
     * 测虫设备code
     * @param id 测虫设备code
     */
    public void setId(String id) {
        this.id = id == null ? null : id.trim();
    }

    /**
     * 
     * @return org_id 
     */
    public String getOrgId() {
        return orgId;
    }

    /**
     * 
     * @param orgId 
     */
    public void setOrgId(String orgId) {
        this.orgId = orgId == null ? null : orgId.trim();
    }

    /**
     * 设备code
     * @return v_cc_code 设备code
     */
    public String getvCcCode() {
        return vCcCode;
    }

    /**
     * 设备code
     * @param vCcCode 设备code
     */
    public void setvCcCode(String vCcCode) {
        this.vCcCode = vCcCode == null ? null : vCcCode.trim();
    }

    /**
     * 站点code
     * @return z_zd_code 站点code
     */
    public String getzZdCode() {
        return zZdCode;
    }

    /**
     * 站点code
     * @param zZdCode 站点code
     */
    public void setzZdCode(String zZdCode) {
        this.zZdCode = zZdCode == null ? null : zZdCode.trim();
    }

    /**
     * 仓房code
     * @return v_cf_code 仓房code
     */
    public String getvCfCode() {
        return vCfCode;
    }

    /**
     * 仓房code
     * @param vCfCode 仓房code
     */
    public void setvCfCode(String vCfCode) {
        this.vCfCode = vCfCode == null ? null : vCfCode.trim();
    }

    /**
     * 
     * @return v_max 
     */
    public Integer getvMax() {
        return vMax;
    }

    /**
     * 
     * @param vMax 
     */
    public void setvMax(Integer vMax) {
        this.vMax = vMax;
    }

    /**
     * 
     * @return v_min 
     */
    public Integer getvMin() {
        return vMin;
    }

    /**
     * 
     * @param vMin 
     */
    public void setvMin(Integer vMin) {
        this.vMin = vMin;
    }

    /**
     * 
     * @return v_avg 
     */
    public BigDecimal getvAvg() {
        return vAvg;
    }

    /**
     * 
     * @param vAvg 
     */
    public void setvAvg(BigDecimal vAvg) {
        this.vAvg = vAvg;
    }

    /**
     * 
     * @return v_update_time 
     */
    public Date getvUpdateTime() {
        return vUpdateTime;
    }

    /**
     * 
     * @param vUpdateTime 
     */
    public void setvUpdateTime(Date vUpdateTime) {
        this.vUpdateTime = vUpdateTime;
    }

    /**
     * 数据来源
     * @return data_source 数据来源
     */
    public String getDataSource() {
        return dataSource;
    }

    /**
     * 数据来源
     * @param dataSource 数据来源
     */
    public void setDataSource(String dataSource) {
        this.dataSource = dataSource == null ? null : dataSource.trim();
    }

	public String getHcjcdh() {
		return hcjcdh;
	}

	public void setHcjcdh(String hcjcdh) {
		this.hcjcdh = hcjcdh == null ? null : hcjcdh.trim();
	}
	
}